import { aws_ec2 as ec2 } from 'aws-cdk-lib';
import * as constructs from 'constructs';
import { StatefulRuleDatabase } from './statefuldatabase';
export declare enum StatefulAction {
    /**
     * Traffic will pass
     */
    PASS = "pass",
    /**
     * Traffic will be droped silently. Note, When will cause a timeout for TCP, Consider using REJECT
     */
    DROP = "drop",
    /**
     * Traffic will be dropped, and a TCP reset sent to the source
     */
    REJECT = "reject",
    /**
     * Raises an alert according to the firewalls logging/alert
     */
    ALERT = "alert"
}
export declare enum FWProtocol {
    TCP = "tcp",
    UPD = "udp",
    ICMP = "icmp",
    IP = "ip",
    HTTP = "http",
    TLS = "tls"
}
export declare enum Direction {
    /**
     * Traffic allowed from Src to destination only
     */
    OUTBOUND = "->",
    /**
     * Traffic allowed in both directions
     */
    BOTH = "<>"
}
export declare type SrcDstAddr = string | PrefixList;
export declare type SrcDstPort = string;
export interface SuricataRuleProps {
    readonly action: StatefulAction;
    readonly protocol: FWProtocol;
    readonly source: SrcDstAddr;
    readonly destination: SrcDstAddr;
    readonly srcPort: SrcDstPort;
    readonly destPort: SrcDstPort;
    readonly direction: Direction;
}
export interface FQDNStatefulRuleProps extends SuricataRuleProps {
    readonly fqdn: string;
    readonly priority?: number | undefined;
    readonly rulesDatabase: StatefulRuleDatabase;
}
export interface PrefixListSetInterface {
    readonly arn: string;
    readonly name: string;
}
declare type PrefixListSet = PrefixListSetInterface;
export declare class FQDNStatefulRule extends constructs.Construct {
    uuid: string;
    prefixListSet: PrefixListSet[];
    constructor(scope: constructs.Construct, id: string, props: FQDNStatefulRuleProps);
}
export declare enum IPAddressFamily {
    IPV4 = "IPv4",
    IPV6 = "IPv6"
}
export interface CidrType {
    readonly cidr: string;
    readonly description?: string;
}
declare type CidrList = CidrType[];
export interface PrefixListProps {
    readonly addressFamily: IPAddressFamily;
    readonly prefixListName: string;
    readonly maxEntries: number;
    readonly entries: CidrList;
}
export declare class PrefixList extends constructs.Construct {
    readonly prefixlist: ec2.CfnPrefixList;
    readonly prefixlistArn: string;
    readonly prefixListSet: PrefixListSet;
    constructor(scope: constructs.Construct, id: string, props: PrefixListProps);
}
export interface SuricataRuleGroupProps {
    readonly ruleGroupName: string;
    readonly description?: string | undefined;
    readonly suricataRules?: FQDNStatefulRule[];
    readonly capacity: number;
    readonly rulesDatabase: StatefulRuleDatabase;
}
export declare class SuricataRuleGroup extends constructs.Construct {
    readonly ruleGroupArn: string;
    private ruleprefixlists;
    private ruleuuidlist;
    constructor(scope: constructs.Construct, id: string, props: SuricataRuleGroupProps);
    addRule(props: FQDNStatefulRule): void;
}
export {};
